@@ -136,6 +136,13 @@ class TestJSONResourceStore(test_monolingual.TestMonolingualStore):
 
         assert out.getvalue() == b'{\n    "key": "value"\n}\n'
 
+    def test_can_not_detect(self):
+        store = self.StoreClass()
+        with raises(base.ParseError):
+            store.parse(
+                b"PK\x03\x04\x14\x00\x06\x00\x08\x00\x00\x00!\x00b\xee\x9dh^\x01\x00\x00\x90\x04\x00\x00\x13\x00\x08\x02"
+            )
+
     def test_error(self):
         store = self.StoreClass()
         with raises(base.ParseError):
@@ -228,6 +235,24 @@ class TestJSONResourceStore(test_monolingual.TestMonolingualStore):
         assert str(unit) == expected.strip()
         assert bytes(store).decode() == expected
 
+    def test_add_blank(self):
+        expected = """{
+    "simple.key": "source"
+}
+"""
+        store = self.StoreClass()
+        store.parse("true")
+
+        unit = self.StoreClass.UnitClass(
+            "source",
+        )
+        assert str(unit) != expected.strip()
+        unit.setid("simple.key")
+        store.addunit(unit)
+
+        assert str(unit) == expected.strip()
+        assert bytes(store).decode() == expected
+
 
 class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
     StoreClass = jsonl10n.JsonNestedFile
@@ -312,6 +337,71 @@ class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
 """
         assert bytes(store).decode() == expected
 
+    def test_add_index_nested(self):
+        store = self.StoreClass()
+        store.parse('{"foo":[["x", "y"]]}')
+
+        assert len(store.units) == 2
+        assert store.units[0].getid() == ".foo[0][0]"
+        assert store.units[1].getid() == ".foo[0][1]"
+
+        unit = self.StoreClass.UnitClass("source")
+        unit.setid("values[2][0]")
+        store.addunit(unit)
+
+        expected = """{
+    "foo": [
+        [
+            "x",
+            "y"
+        ]
+    ],
+    "values": [
+        [],
+        [],
+        [
+            "source"
+        ]
+    ]
+}
+"""
+        assert bytes(store).decode() == expected
+
+    def test_nested_list_mixed(self):
+        data = """{
+    "story_9795": {
+        "tsr_0": [
+            [
+                "‥",
+                "Combinato Carcer Tullianum & parco"
+            ],
+            "Archeologico del Colosseo"
+        ]
+    }
+}
+"""
+        store = self.StoreClass()
+        store.parse(data)
+        assert len(store.units) == 3
+        assert store.units[0].getid() == ".story_9795.tsr_0[0][0]"
+        assert store.units[1].getid() == ".story_9795.tsr_0[0][1]"
+        assert store.units[2].getid() == ".story_9795.tsr_0[1]"
+
+        assert bytes(store).decode() == data
+
+        store = self.StoreClass()
+        unit = self.StoreClass.UnitClass("Archeologico del Colosseo")
+        unit.setid(".story_9795.tsr_0[1]")
+        store.addunit(unit)
+        unit = self.StoreClass.UnitClass("Combinato Carcer Tullianum & parco")
+        unit.setid(".story_9795.tsr_0[0][1]")
+        store.addunit(unit)
+        unit = self.StoreClass.UnitClass("‥")
+        unit.setid(".story_9795.tsr_0[0][0]")
+        store.addunit(unit)
+
+        assert bytes(store).decode() == data
+
     def test_list_to_dict(self):
         data = """{
     "userInfoPage": [
