@@ -137,7 +137,8 @@ class TestTSUnit(test_base.TestTranslationUnit):
 class TestTSfile(test_base.TestTranslationStore):
     StoreClass = ts.tsfile
 
-    def test_basic(self):
+    @staticmethod
+    def test_basic():
         tsfile = ts.tsfile()
         assert tsfile.units == []
         tsfile.addsourceunit("Bla")
@@ -149,7 +150,8 @@ class TestTSfile(test_base.TestTranslationStore):
         assert newfile.findunit("Bla").source == "Bla"
         assert newfile.findunit("dit") is None
 
-    def test_source(self):
+    @staticmethod
+    def test_source():
         tsfile = ts.tsfile()
         tsunit = tsfile.addsourceunit("Concept")
         tsunit.source = "Term"
@@ -158,7 +160,8 @@ class TestTSfile(test_base.TestTranslationStore):
         assert newfile.findunit("Concept") is None
         assert newfile.findunit("Term") is not None
 
-    def test_target(self):
+    @staticmethod
+    def test_target():
         tsfile = ts.tsfile()
         tsunit = tsfile.addsourceunit("Concept")
         tsunit.target = "Konsep"
@@ -166,7 +169,8 @@ class TestTSfile(test_base.TestTranslationStore):
         print(bytes(tsfile))
         assert newfile.findunit("Concept").target == "Konsep"
 
-    def test_plurals(self):
+    @staticmethod
+    def test_plurals():
         """Test basic plurals"""
         tsfile = ts.tsfile()
         tsunit = tsfile.addsourceunit("File(s)")
@@ -177,7 +181,8 @@ class TestTSfile(test_base.TestTranslationStore):
         assert checkunit.target == ["Leêr", "Leêrs"]
         assert checkunit.hasplural()
 
-    def test_nplural(self):
+    @staticmethod
+    def test_nplural():
         tsstr = """<!DOCTYPE TS>
 <TS version="2.0" language="xx" sourcelanguage="de">
 </TS>
@@ -187,7 +192,8 @@ class TestTSfile(test_base.TestTranslationStore):
         tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
         assert tsfile.nplural() == 3
 
-    def test_language(self):
+    @staticmethod
+    def test_language():
         """Check that we can get and set language and sourcelanguage in the header"""
         tsstr = """<!DOCTYPE TS>
 <TS version="2.0" language="fr" sourcelanguage="de">
@@ -207,7 +213,8 @@ class TestTSfile(test_base.TestTranslationStore):
         tsfile = ts.tsfile.parsestring(tsstr)
         assert tsfile.getsourcelanguage() == "en"
 
-    def test_edit(self):
+    @staticmethod
+    def test_edit():
         """test editing works well"""
         tsstr = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
@@ -231,7 +238,8 @@ class TestTSfile(test_base.TestTranslationStore):
         newtsstr = tsstr.replace(">TargetString", ' type="unfinished">TestTarget')
         assert newtsstr == bytes(tsfile).decode("utf-8")
 
-    def test_obsolete(self):
+    @staticmethod
+    def test_obsolete():
         tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
         assert tsfile.units[0].istranslatable()
         assert not tsfile.units[0].isobsolete()
@@ -245,7 +253,8 @@ class TestTSfile(test_base.TestTranslationStore):
         assert not tsfile.units[2].istranslatable()
         assert tsfile.units[2].isobsolete()
 
-    def test_locations(self):
+    @staticmethod
+    def test_locations():
         """test that locations work well"""
         tsstr = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
@@ -283,7 +292,8 @@ class TestTSfile(test_base.TestTranslationStore):
         assert tsfile.units[2].getlocations() == []
         assert tsfile.units[3].getlocations() == []
 
-    def test_merge_with_fuzzies(self):
+    @staticmethod
+    def test_merge_with_fuzzies():
         """test that merge with fuzzy works well"""
         tsstr1 = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
@@ -332,19 +342,22 @@ class TestTSfile(test_base.TestTranslationStore):
         assert tsfile2.units[0].isfuzzy()
         assert not tsfile2.units[1].isfuzzy()
 
-    def test_getid(self):
+    @staticmethod
+    def test_getid():
         """test that getid works well"""
         tsfile = ts.tsfile.parsestring(TS_NUMERUS)
         assert tsfile.units[0].getid() == "Dialog2%n files"
         assert tsfile.units[1].getid() == "Dialog2\nthis_is_some_id%n cars"
         assert tsfile.units[3].getid() == "Dialog2\nthis_is_another_idfunc3"
 
-    def test_backnforth(self):
+    @staticmethod
+    def test_backnforth():
         """test that ts files are read and output properly"""
         tsfile = ts.tsfile.parsestring(TS_NUMERUS)
         assert bytes(tsfile).decode("utf-8") == TS_NUMERUS
 
-    def test_context(self):
+    @staticmethod
+    def test_context():
         tsfile = ts.tsfile.parsestring(TS_NUMERUS)
         unit = tsfile.units[0]
 
@@ -369,13 +382,15 @@ class TestTSfile(test_base.TestTranslationStore):
         newunit.setcontext("Some context")
         assert newunit.getcontext() == "Some context"
 
-    def test_roundtrip_context(self):
+    @staticmethod
+    def test_roundtrip_context():
         tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
         assert bytes(tsfile).decode("utf-8") == TS_CONTEXT_QT4
         tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT5)
         assert bytes(tsfile).decode("utf-8") == TS_CONTEXT_QT5
 
-    def test_edit_missing_translation(self):
+    @staticmethod
+    def test_edit_missing_translation():
         """test editing with missing translation element works well"""
         tsstr = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
